==> mgb-0.6.2.tar.gz: language/lang_german_utf8/lang_import.php <==
<?php
	
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2007 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ======================================= //
	// lang_import.php - non formal German 1.0 //
	// ======================================= //
	//
	// This languagefile was edited by Christian Rech alias HeyJ (mail@heyj.de)
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //
	
	// header
	$lang['h_title'] = "Import der Daten einer &auml;lteren Version";
	
	// general
	$lang['next_step'] = "&raquo; Weiter &raquo;";
	$lang['yes'] = "Ja";
	$lang['no'] = "Nein";
	$lang['active'] = "Aktiv";
	$lang['inactive'] = "Inaktiv";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "fehlgeschlagen!";
		
	// installation
	$lang['title'] = "Import der Daten einer &auml;lteren Version";
	
	$lang['expl_import'] = "Bitte gib die Verbindungsdaten der Datenbank an, in der sich die Installation Ihres alten MGB G&auml;stebuches befindet. Zus&auml;tzlich musst du den absoluten Pfad zu deiner alten Installation <b>ohne den Domainnamen</b> angeben. z.B.: Anstatt <i>http://www.beispiel.de/php/mgb/</i> nur <i>/php/mgb/</i>. Beachte dabei die Schr&auml;gstriche am Anfang und am Ende.";
	
	// step 1
	$lang['db_title'] = "Datenbankinformationen:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Datenbankname:";
	$lang['db_username'] = "Benutzername:";
	$lang['db_password'] = "Passwort:";
	$lang['oldgb_path'] = "Pfad:";
	$lang['import_settings'] = "Einstellungen importieren:";
	
	// errormessages step 1
	$lang['no_error'] = "Alle angegebenen Werte sind OK!";
	$lang['error_1_step1'] = "Bitte f&uuml;lle alle Felder aus!";
	$lang['error_2_step1'] = "Die Verbindung zur Datenbank ist fehlgeschlagen, &uuml;berpr&uuml;fe Deine Zugangsdaten.";
	$lang['error_3_step1'] = "In dem von Dir angegebenen Pfad konnte keine MGB Installation gefunden werden.";
	$lang['error_4_step1'] = "Die von Dir angegebene Datenbank ist OK, aber es konnte keine fr&uuml;here Installation darin gefunden werden.";
	
	// step 2
	$lang['transfer_settings'] = "&uuml;bertrage Einstellungen...";
	$lang['transfer_entries'] = "&uuml;bertrage Eintr&auml;ge...";
	
	// finish
	$lang['import_finish'] = "Herzlichen Gl&uuml;ckwunsch!<br><br>Die Daten deiner alten MGB Installation wurden erfolgreich in das MGB ".MGB_VERSION." &uuml;bertragen.<br><br><a href='../admin/admin.php' title='Zur Administration'>Zur Administration</a><br><a href='../index.php' title='Zum G&auml;stebuch'>Zum G&auml;stebuch</a>";
?>

==> mgb-0.6.5.tar.gz: language/lang_german_utf8/lang_import.php <==
<?php
	/*
	MGB 0.6.x - OpenSource PHP and MySql Guestbook
	Copyright (C) 2004 - 2011 Juergen Grueneisl - http://www.m-gb.org/

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
	*/

	// ============================ //
	// lang_import.php - German 1.2 //
	// ============================ //
	//
	// ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ //

	// header
	$lang['h_title'] = "Import der Daten einer &auml;lteren Version";

	// general
	$lang['next_step'] = "&raquo; Weiter &raquo;";
	$lang['yes'] = "Ja";
	$lang['no'] = "Nein";
	$lang['active'] = "Aktiv";
	$lang['inactive'] = "Inaktiv";
	$lang['ok'] = "OK!";
	$lang['not_ok'] = "fehlgeschlagen!";

	// installation
	$lang['title'] = "Import der Daten einer &auml;lteren Version";

	$lang['expl_import'] = "Bitte gib die Verbindungsdaten der Datenbank an, in der sich die Installation Ihres alten MGB G&auml;stebuches befindet. Zus&auml;tzlich musst du den absoluten Pfad zu deiner alten Installation <b>ohne den Domainnamen</b> angeben. z.B.: Anstatt <i>http://www.beispiel.de/php/mgb/</i> nur <i>/php/mgb/</i>. Beachte dabei die Schr&auml;gstriche am Anfang und am Ende.";

	// step 1
	$lang['db_title'] = "Datenbankinformationen:";
	$lang['db_hostname'] = "Host:";
	$lang['db_dbname'] = "Datenbankname:";
	$lang['db_username'] = "Benutzername:";
	$lang['db_password'] = "Passwort:";
	$lang['oldgb_path'] = "Pfad:";
	$lang['import_settings'] = "Einstellungen importieren:";

	// errormessages step 1
	$lang['no_error'] = "Alle angegebenen Werte sind OK!";
	$lang['error_1_step1'] = "Bitte f&uuml;lle alle Felder aus!";
	$lang['error_2_step1'] = "Die Verbindung zur Datenbank ist fehlgeschlagen, &uuml;berpr&uuml;fe Deine Zugangsdaten.";
	$lang['error_3_step1'] = "In dem von Dir angegebenen Pfad konnte keine MGB Installation gefunden werden.";
	$lang['error_4_step1'] = "Die von Dir angegebene Datenbank ist OK, aber es konnte keine fr&uuml;here Installation darin gefunden werden.";

	// step 2
	$lang['transfer_settings'] = "&uuml;bertrage Einstellungen...";
	$lang['transfer_entries'] = "&uuml;bertrage Eintr&auml;ge...";

	// finish
	$lang['import_finish'] = "Herzlichen Gl&uuml;ckwunsch!<br><br>Die Daten deiner alten MGB Installation wurden erfolgreich in das MGB ".MGB_VERSION." &uuml;bertragen.<br><br><a href='../admin/admin.php' title='Zur Administration'>Zur Administration</a><br><a href='../index.php' title='Zum G&auml;stebuch'>Zum G&auml;stebuch</a>";
?>
